/***************************************************************************
 *   Copyright (C) 2010 Nicolas Hadacek <hadacek@kde.org>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#ifndef VIEWER_H
#define VIEWER_H

#ifdef NO_KDE
#  include "common/nokde_gui/nokde_text_editor.h"
#else
#  include <kparts/part.h>
#  include <ktexteditor/view.h>
#  include <ktexteditor/document.h>
#endif

#endif
